==> mingw-w64-clang-aarch64-qt6-static-6.8.2-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6Quick3DTools/Qt6Quick3DToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::balsam" for configuration "Release"
set_property(TARGET Qt6::balsam APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsam PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/balsam.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::balsam )
list(APPEND _cmake_import_check_files_for_Qt6::balsam "${_IMPORT_PREFIX}/bin/balsam.exe" )

# Import target "Qt6::balsamui" for configuration "Release"
set_property(TARGET Qt6::balsamui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsamui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/balsamui.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::balsamui )
list(APPEND _cmake_import_check_files_for_Qt6::balsamui "${_IMPORT_PREFIX}/bin/balsamui.exe" )

# Import target "Qt6::meshdebug" for configuration "Release"
set_property(TARGET Qt6::meshdebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::meshdebug PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/meshdebug.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::meshdebug )
list(APPEND _cmake_import_check_files_for_Qt6::meshdebug "${_IMPORT_PREFIX}/bin/meshdebug.exe" )

# Import target "Qt6::shadergen" for configuration "Release"
set_property(TARGET Qt6::shadergen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shadergen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/shadergen.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::shadergen )
list(APPEND _cmake_import_check_files_for_Qt6::shadergen "${_IMPORT_PREFIX}/bin/shadergen.exe" )

# Import target "Qt6::instancer" for configuration "Release"
set_property(TARGET Qt6::instancer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::instancer PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/instancer.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::instancer )
list(APPEND _cmake_import_check_files_for_Qt6::instancer "${_IMPORT_PREFIX}/bin/instancer.exe" )

# Import target "Qt6::shapegen" for configuration "Release"
set_property(TARGET Qt6::shapegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shapegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/shapegen.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::shapegen )
list(APPEND _cmake_import_check_files_for_Qt6::shapegen "${_IMPORT_PREFIX}/bin/shapegen.exe" )

# Import target "Qt6::materialeditor" for configuration "Release"
set_property(TARGET Qt6::materialeditor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::materialeditor PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/materialeditor.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::materialeditor )
list(APPEND _cmake_import_check_files_for_Qt6::materialeditor "${_IMPORT_PREFIX}/bin/materialeditor.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-static-6.10.1-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6Quick3DTools/Qt6Quick3DToolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::balsam" for configuration "Release"
set_property(TARGET Qt6::balsam APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsam PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/balsam.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::balsam )
list(APPEND _cmake_import_check_files_for_Qt6::balsam "${_IMPORT_PREFIX}/bin/balsam.exe" )

# Import target "Qt6::balsamui" for configuration "Release"
set_property(TARGET Qt6::balsamui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::balsamui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/balsamui.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::balsamui )
list(APPEND _cmake_import_check_files_for_Qt6::balsamui "${_IMPORT_PREFIX}/bin/balsamui.exe" )

# Import target "Qt6::meshdebug" for configuration "Release"
set_property(TARGET Qt6::meshdebug APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::meshdebug PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/meshdebug.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::meshdebug )
list(APPEND _cmake_import_check_files_for_Qt6::meshdebug "${_IMPORT_PREFIX}/bin/meshdebug.exe" )

# Import target "Qt6::shadergen" for configuration "Release"
set_property(TARGET Qt6::shadergen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shadergen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/shadergen.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::shadergen )
list(APPEND _cmake_import_check_files_for_Qt6::shadergen "${_IMPORT_PREFIX}/bin/shadergen.exe" )

# Import target "Qt6::instancer" for configuration "Release"
set_property(TARGET Qt6::instancer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::instancer PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/instancer.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::instancer )
list(APPEND _cmake_import_check_files_for_Qt6::instancer "${_IMPORT_PREFIX}/bin/instancer.exe" )

# Import target "Qt6::shapegen" for configuration "Release"
set_property(TARGET Qt6::shapegen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::shapegen PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/shapegen.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::shapegen )
list(APPEND _cmake_import_check_files_for_Qt6::shapegen "${_IMPORT_PREFIX}/bin/shapegen.exe" )

# Import target "Qt6::materialeditor" for configuration "Release"
set_property(TARGET Qt6::materialeditor APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::materialeditor PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/materialeditor.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::materialeditor )
list(APPEND _cmake_import_check_files_for_Qt6::materialeditor "${_IMPORT_PREFIX}/bin/materialeditor.exe" )

# Import target "Qt6::lightmapviewer" for configuration "Release"
set_property(TARGET Qt6::lightmapviewer APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::lightmapviewer PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/lightmapviewer.exe"
  )

list(APPEND _cmake_import_check_targets Qt6::lightmapviewer )
list(APPEND _cmake_import_check_files_for_Qt6::lightmapviewer "${_IMPORT_PREFIX}/bin/lightmapviewer.exe" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
